/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import url from 'url';
import { synthtrace } from '../../../synthtrace';
import { opbeans } from '../../fixtures/synthtrace/opbeans';
import { checkA11y } from '../../support/commands';

const start = '2021-10-10T00:00:00.000Z';
const end = '2021-10-10T00:15:00.000Z';

const serviceTransactionsHref = url.format({
  pathname: '/app/apm/services/opbeans-node/transactions',
  query: { rangeFrom: start, rangeTo: end },
});

describe('Transactions Overview', () => {
  before(() => {
    synthtrace.index(
      opbeans({
        from: new Date(start).getTime(),
        to: new Date(end).getTime(),
      })
    );
  });

  after(() => {
    synthtrace.clean();
  });

  beforeEach(() => {
    cy.loginAsViewerUser();
  });

  it('has no detectable a11y violations on load', () => {
    cy.visitKibana(serviceTransactionsHref);
    cy.get('a:contains(Transactions)').should('have.attr', 'aria-selected', 'true');
    // set skipFailures to true to not fail the test when there are accessibility failures
    checkA11y({ skipFailures: true });
  });

  it('persists transaction type selected when navigating to Overview tab', () => {
    cy.visitKibana(serviceTransactionsHref);
    cy.getByTestSubj('headerFilterTransactionType').should('have.value', 'request');
    cy.getByTestSubj('headerFilterTransactionType').select('Worker');
    cy.getByTestSubj('headerFilterTransactionType').should('have.value', 'Worker');
    cy.get('a[href*="/app/apm/services/opbeans-node/overview"]').click();
    cy.getByTestSubj('headerFilterTransactionType').should('have.value', 'Worker');
  });
});
