/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import { EuiFlexGroup, EuiFlexItem, EuiLink, EuiToolTip, EuiButtonIcon } from '@elastic/eui';
import { TechnicalPreviewBadge } from '@kbn/observability-shared-plugin/public';
import React from 'react';
import { i18n } from '@kbn/i18n';
import { FormattedMessage } from '@kbn/i18n-react';
import { useKibana } from '@kbn/kibana-react-plugin/public';
import type { ApmPluginStartDeps } from '../../../../plugin';

interface EntitiesInventoryCalloutProps {
  onDismiss: () => void;
}

export function EntitiesInventoryCallout({ onDismiss }: EntitiesInventoryCalloutProps) {
  const { services } = useKibana<ApmPluginStartDeps>();
  const { observabilityShared } = services;

  const entitiesInventoryLocator = observabilityShared.locators.entitiesInventory;

  return (
    <EuiFlexGroup direction="row" alignItems="center" gutterSize="xs">
      <EuiFlexItem grow={false}>
        <TechnicalPreviewBadge icon="beaker" style={{ verticalAlign: 'middle' }} />
      </EuiFlexItem>
      <EuiFlexItem grow={false}>
        <EuiLink
          data-test-subj="apmEntitiesInventoryCalloutLink"
          href={entitiesInventoryLocator.useUrl({})}
        >
          <FormattedMessage
            id="xpack.apm.entitiesInventoryCallout.linklabel"
            defaultMessage="Try our new Inventory!"
          />
        </EuiLink>
      </EuiFlexItem>
      <EuiFlexItem grow={false}>
        <EuiToolTip
          content={
            <FormattedMessage
              id="xpack.apm.entitiesInventoryCallout.linkTooltip"
              defaultMessage="Hide this"
            />
          }
        >
          <EuiButtonIcon
            data-test-subj="apmEntitiesInventoryCalloutDismiss"
            aria-label={i18n.translate('xpack.apm.entitiesInventoryCallout.ariaLabel', {
              defaultMessage: 'Hide the entities inventory callout',
            })}
            iconType="cross"
            onClick={onDismiss}
          />
        </EuiToolTip>
      </EuiFlexItem>
    </EuiFlexGroup>
  );
}
