/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import { EuiEmptyPrompt, EuiLoadingLogo } from '@elastic/eui';
import React, { memo } from 'react';
import { i18n } from '@kbn/i18n';
import { useFetchIntegrations } from '../../hooks/alert_summary/use_fetch_integrations';
import { LandingPage } from '../../components/alert_summary/landing_page/landing_page';
import { Wrapper } from '../../components/alert_summary/wrapper';

export const LOADING_INTEGRATIONS_TEST_ID = 'alert-summary-loading-integrations';

const LOADING_INTEGRATIONS = i18n.translate('xpack.securitySolution.alertSummary.loading', {
  defaultMessage: 'Loading integrations',
});

/**
 * Alert summary page rendering alerts generated by AI for SOC integrations.
 * This page should be only rendered for the AI for SOC product line.
 */
export const AlertSummaryPage = memo(() => {
  const { availablePackages, installedPackages, isLoading } = useFetchIntegrations();

  if (isLoading) {
    return (
      <EuiEmptyPrompt
        data-test-subj={LOADING_INTEGRATIONS_TEST_ID}
        icon={<EuiLoadingLogo logo="logoSecurity" size="xl" />}
        title={<h2>{LOADING_INTEGRATIONS}</h2>}
      />
    );
  }

  if (installedPackages.length === 0) {
    return <LandingPage packages={availablePackages} />;
  }

  return <Wrapper packages={installedPackages} />;
});

AlertSummaryPage.displayName = 'AlertSummaryPage';
